@@ -25,7 +25,7 @@
 #include <QtDBus>
 #include <QTreeWidget>
 
-ConjugationOptions::ConjugationOptions(KEduVocDocument* doc, QWidget * parent)
+ConjugationOptions::ConjugationOptions(KEduVocDocument *doc, QWidget *parent)
     : QWidget(parent)
     , m_doc(doc)
     , m_language(0)
@@ -37,6 +37,8 @@ ConjugationOptions::ConjugationOptions(KEduVocDocument* doc, QWidget * parent)
     layout->addWidget(m_treeWidget);
     layout->setMargin(0);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
+    connect(m_treeWidget, &QTreeWidget::itemChanged,
+            this, &ConjugationOptions::processCheckBoxChanged);
 }
 
 void ConjugationOptions::setLanguages(int from, int to)
@@ -51,7 +53,9 @@ void ConjugationOptions::setLanguages(int from, int to)
 
 void ConjugationOptions::setupTenses()
 {
+    m_treeWidget->blockSignals(true);
     m_treeWidget->clear();
+    m_checkStates.clear();
 
     DocumentSettings documentSettings(m_doc->url().url() + QString::number(m_language));
     documentSettings.load();
@@ -64,21 +68,27 @@ void ConjugationOptions::setupTenses()
         tenseItem->setText(0, tenseName);
         if (activeTenses.contains(tenseName)) {
             tenseItem->setCheckState(0, Qt::Checked);
+            m_checkStates[tenseItem] = Qt::Checked;
         } else {
             tenseItem->setCheckState(0, Qt::Unchecked);
+            m_checkStates[tenseItem] = Qt::Unchecked;
         }
         tenseItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsUserCheckable);
         m_treeWidget->addTopLevelItem(tenseItem);
     }
+    m_treeWidget->blockSignals(false);
 }
 
 void ConjugationOptions::updateSettings()
 {
     qDebug() << "Save language selection";
-    QTreeWidgetItem* parentItem = m_treeWidget->invisibleRootItem();
+    QTreeWidgetItem *parentItem = m_treeWidget->invisibleRootItem();
+    if (parentItem == nullptr) {
+        return;
+    }
     QStringList activeTenses;
     for (int i = 0; i < parentItem->childCount(); i++) {
-        QTreeWidgetItem* tenseItem = parentItem->child(i);
+        QTreeWidgetItem *tenseItem = parentItem->child(i);
         if (tenseItem->checkState(0) == Qt::Checked) {
             activeTenses.append(tenseItem->text(0));
         }
@@ -87,3 +97,17 @@ void ConjugationOptions::updateSettings()
     documentSettings.setConjugationTenses(activeTenses);
     documentSettings.save();
 }
+
+void ConjugationOptions::processCheckBoxChanged(QTreeWidgetItem *item, int column)
+{
+    if (column != 0) {
+        return;
+    }
+    Qt::CheckState newCheckState = item->checkState(column);
+    if (m_checkStates.contains(item) && (m_checkStates[item] != newCheckState)) {
+        m_checkStates[item] = newCheckState;
+        updateSettings();
+        emit checkBoxChanged();
+    }
+}
+
