@@ -15,26 +15,36 @@
 #define CONJUGATIONOPTIONS_H
 
 #include <QtWidgets/QWidget>
+#include <QMap>
 
 class KEduVocDocument;
 class QTreeWidget;
+class QTreeWidgetItem;
 
 class ConjugationOptions : public QWidget
 {
     Q_OBJECT
 public:
-    ConjugationOptions(KEduVocDocument* doc, QWidget *parent);
+    ConjugationOptions(KEduVocDocument *doc, QWidget *parent);
 
 public Q_SLOTS:
     void setLanguages(int from, int to);
     void updateSettings();
 
+signals:
+    void checkBoxChanged();
+
 private:
     void setupTenses();
 
-    KEduVocDocument* m_doc;
+private slots:
+    void processCheckBoxChanged(QTreeWidgetItem *item, int column);
+
+private:
+    KEduVocDocument *m_doc;
     int m_language;
-    QTreeWidget* m_treeWidget;
+    QTreeWidget *m_treeWidget;
+    QMap<QTreeWidgetItem*, Qt::CheckState> m_checkStates;
 };
 
 #endif
